@@ -1,32 +1,22 @@
-import math
-
-from notecoin.strategy.utils import account_api, market_api, trade_api
+from notecoin.strategy.utils import trade_api
 
 
 class OkexCoin:
-    def __init__(self, coin_id='METIS-USDT', count=0.):
+    def __init__(self, coin_id='METIS-USDT', price=0, count=0.):
         self.coin_id = coin_id
         self.count = count
-        self.price_in = self.current_price
+        self.price_in = price
         self.price = self.price_in
 
-    @property
-    def current_price(self):
-        self.price = float(market_api.get_ticker(self.coin_id).data[0]['last'])
-        return self.price
-
     @property
     def money(self):
         return self.price * self.count
 
     def buy(self):
-        print("sell")
         return trade_api.place_order(instId=self.coin_id, tdMode='cash', side='buy', ordType='market', sz='50')
 
     def sell(self):
-        coin_dict = dict([(line['ccy'], line['availBal']) for line in account_api.get_account().data[0]['details']])
-        count = coin_dict[self.coin_id.split('-')[0]]
-        return trade_api.place_order(instId=self.coin_id, tdMode='cash', side='sell', ordType='market', sz=count)
+        return trade_api.place_order(instId=self.coin_id, tdMode='cash', side='sell', ordType='market', sz=self.count)
 
     @staticmethod
     def instance_by_account(data):
